The active URL area rotates when link text is rotated
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
When link text is rotated in a matplotlib figure, the active URL
area will now include the link area. Previously, the active area
remained in the original, non-rotated, position.
